@@ -1,5 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2008-2013 Red Hat, Inc.
  *
  * Licensed under GPL version 2 or later.
@@ -26,7 +25,6 @@ typedef struct
   guint64 value;
 } Sample;
 
-typedef struct _GduEstimatorClass GduEstimatorClass;
 struct _GduEstimator
 {
   GObject parent;
@@ -40,11 +38,6 @@ struct _GduEstimator
   guint num_samples;
 };
 
-struct _GduEstimatorClass
-{
-  GObjectClass parent_class;
-};
-
 enum
 {
   PROP_0,
@@ -56,14 +49,6 @@ enum
 
 G_DEFINE_TYPE (GduEstimator, gdu_estimator, G_TYPE_OBJECT)
 
-static void
-gdu_estimator_finalize (GObject *object)
-{
-  //GduEstimator *estimator = GDU_ESTIMATOR (object);
-
-  G_OBJECT_CLASS (gdu_estimator_parent_class)->finalize (object);
-}
-
 static void
 gdu_estimator_get_property (GObject    *object,
                             guint       property_id,
@@ -164,7 +149,6 @@ gdu_estimator_class_init (GduEstimatorClass *klass)
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->get_property = gdu_estimator_get_property;
   gobject_class->set_property = gdu_estimator_set_property;
-  gobject_class->finalize     = gdu_estimator_finalize;
 
   g_object_class_install_property (gobject_class, PROP_TARGET_BYTES,
                                    g_param_spec_uint64 ("target-bytes", NULL, NULL,
