@@ -1,5 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2008-2013 Red Hat, Inc.
  *
  * Licensed under GPL version 2 or later.
@@ -15,6 +14,10 @@
 
 G_BEGIN_DECLS
 
+#define GDU_TYPE_FILESYSTEM_DIALOG (gdu_filesystem_dialog_get_type ())
+
+G_DECLARE_FINAL_TYPE (GduFilesystemDialog, gdu_filesystem_dialog, GDU, FILESYSTEM_DIALOG, GtkDialog)
+
 void   gdu_filesystem_dialog_show (GduWindow    *window,
                                    UDisksObject *object);
 
